/**
 *  Copyright 2011 Terracotta, Inc.
 *  Copyright 2011 Oracle America Incorporated
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.jsr107.ri;

import javax.cache.Cache;
import javax.cache.CacheMXBean;
import javax.cache.transaction.IsolationLevel;
import javax.cache.transaction.Mode;

/**
 * Class to help implementers
 *
 * @param <K> the type of keys maintained by this map
 * @param <V> the type of mapped values*
 * @author Yannis Cosmadopoulos
 * @since 1.0
 */
public class RICacheMXBean<K, V> implements CacheMXBean {
    private final Cache<K, V> cache;

    /**
     * Constructor
     *
     * @param cache the cache
     */
    public RICacheMXBean(Cache<K, V> cache) {
        this.cache = cache;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isReadThrough() {
        return cache.getConfiguration().isReadThrough();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isWriteThrough() {
        return cache.getConfiguration().isWriteThrough();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isStoreByValue() {
        return cache.getConfiguration().isStoreByValue();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isStatisticsEnabled() {
        return cache.getConfiguration().isStatisticsEnabled();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isManagementEnabled() {
        return cache.getConfiguration().isManagementEnabled();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isTransactionsEnabled() {
        return cache.getConfiguration().isTransactionsEnabled();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public IsolationLevel getTransactionIsolationLevel() {
        return cache.getConfiguration().getTransactionIsolationLevel();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Mode getTransactionMode() {
        return cache.getConfiguration().getTransactionMode();
    }

//    @Override
//    public ExpiryPolicy getExpiryPolicyFactory() {
//        return null;  //To change body of implemented methods use File | Settings | File Templates.
//    }
}
